import React from 'react';
import PropTypes from 'prop-types';
import { useStaticQuery, graphql } from 'gatsby';
import { FlexWrapper, Paragraph, Image } from '@thepuzzlers/pieces';

export const ThePuzzlersLink = ({ locale }) => {
  const { puzzlersLogo } = useStaticQuery(graphql`
    query {
      puzzlersLogo: file(relativePath: { eq: "puzzlers-logo.svg" }) {
        id
        publicURL
      }
    }
  `);

  return (
    <a
      href={
        locale === 'de'
          ? 'https://thepuzzlers.io/de/'
          : 'https://thepuzzlers.io/'
      }
      style={{ cursor: 'pointer' }}>
      <FlexWrapper sx={{ flexDirection: 'column' }}>
        <Paragraph sx={{ textAlign: 'left' }}>
          {locale === 'de' ? 'Eine Webseite von' : 'A website by'}
        </Paragraph>

        <Image
          sx={{
            height: ['30px', '30px']
          }}
          src={puzzlersLogo.publicURL}
          alt="Logo of The Puzzles"
        />
      </FlexWrapper>
    </a>
  );
};

ThePuzzlersLink.propTypes = {
  locale: PropTypes.string
};

ThePuzzlersLink.defaultProps = {
  locale: 'en'
};
